==> kubernetes-client-4.13.0-sources.jar: io/fabric8/kubernetes/client/dsl/internal/networking/v1/IngressClassOperationsImpl.java <==

                                          
  

package io.fabric8.kubernetes.client.dsl.internal.networking.v1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.networking.v1.DoneableIngressClass;
import io.fabric8.kubernetes.api.model.networking.v1.IngressClass;
import io.fabric8.kubernetes.api.model.networking.v1.IngressClassList;
import io.fabric8.kubernetes.api.model.networking.v1.DoneableIngressClass;

import java.util.Map;
import java.util.TreeMap;


public class IngressClassOperationsImpl extends HasMetadataOperation<IngressClass, IngressClassList, DoneableIngressClass, Resource<IngressClass, DoneableIngressClass>> {

  public IngressClassOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public IngressClassOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public IngressClassOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("networking.k8s.io")
    .withApiGroupVersion("v1")
    .withPlural("ingressclasses"));
    this.type = IngressClass.class;
    this.listType = IngressClassList.class;
    this.doneableType = DoneableIngressClass.class;
  }

  public IngressClassOperationsImpl newInstance(OperationContext context) {
    return new IngressClassOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}

==> kubernetes-client-5.4.1-sources.jar: io/fabric8/kubernetes/client/dsl/internal/networking/v1/IngressClassOperationsImpl.java <==

                                          
  

package io.fabric8.kubernetes.client.dsl.internal.networking.v1;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.networking.v1.IngressClass;
import io.fabric8.kubernetes.api.model.networking.v1.IngressClassBuilder;
import io.fabric8.kubernetes.api.model.networking.v1.IngressClassList;

import java.util.Map;
import java.util.TreeMap;


public class IngressClassOperationsImpl extends HasMetadataOperation<IngressClass, IngressClassList, Resource<IngressClass>> {

  public IngressClassOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public IngressClassOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public IngressClassOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("networking.k8s.io")
    .withApiGroupVersion("v1")
    .withPlural("ingressclasses"));
    this.type = IngressClass.class;
    this.listType = IngressClassList.class;
  }

  public IngressClassOperationsImpl newInstance(OperationContext context) {
    return new IngressClassOperationsImpl(context);
  }

  @Override
  public IngressClass edit(Visitor... visitors) {
    return patch(new IngressClassBuilder(getMandatory()).accept(visitors).build());
  }

  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}
